@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 # (c) 2018 Andreas Motl <andreas@hiveeyes.org>
 import logging
-from builtins import object
 import re
 import attr
 import pandas as pd
@@ -12,7 +11,7 @@ logger = logging.getLogger(__name__)
 
 
 @attr.s
-class DwdCdcClient(object):
+class DwdCdcClient:
     """
     Base functionality for conveniently accessing the Climate Data Center (CDC)
     FTP server operated by »Deutscher Wetterdienst« (DWD).
@@ -26,7 +25,7 @@ class DwdCdcClient(object):
 
     def get_dataframe(self, url=None, path=None, index_column=None, coerce_int=False):
         """
-        Read single CSV file from FTP url and convert to Pandas DataFrame object.
+        Read single CSV file from FTP url and convert to pandas DataFrame object.
 
         Obtains either a full ``url`` parameter or a ``path`` parameter
         for addressing the remote resource. If the ``path`` parameter is given,
@@ -89,7 +88,7 @@ class DwdCdcClient(object):
 
     def csv_to_dataframe(self, stream, index_column=None, coerce_int=False):
         """
-        Read CSV data from stream into Pandas DataFrame object.
+        Read CSV data from stream into pandas DataFrame object.
 
         Optionally obtains ``index_column`` parameter.
         Use this to set the index of designated index column.
@@ -102,13 +101,13 @@ class DwdCdcClient(object):
         #if not stream or stream.len == 0:
         #    return
 
-        # Read CSV into Pandas DataFrame
-        # https://pandas.pydata.org/pandas-docs/stable/io.html
+        # Read CSV into pandas DataFrame.
+        # https://pandas.pydata.org/pandas-docs/stable/user_guide/io.html#csv-text-files
         df = pd.read_csv(
             stream, engine='c', encoding='utf-8',
             delimiter=';', skipinitialspace=True,
             skip_blank_lines=True,
-            error_bad_lines=False,
+            on_bad_lines="warn",
             low_memory=False
         )
 
