@@ -1,21 +1,19 @@
 # -*- coding: utf-8 -*-
 # (c) 2018 Andreas Motl <andreas@hiveeyes.org>
 from __future__ import print_function
-from builtins import object
 import attr
 import json
 import logging
 import pandas as pd
 import pkg_resources
-from tqdm import tqdm
 from datetime import datetime
-from phenodata.util import haversine_distance
+from phenodata.util import haversine_distance, iterate_with_progressbar
 
 logger = logging.getLogger(__name__)
 
 
 @attr.s
-class DwdPhenoData(object):
+class DwdPhenoData:
     """
     Conveniently access phenology information from the Climate Data Center (CDC)
     FTP server operated by »Deutscher Wetterdienst« (DWD).
@@ -122,23 +120,13 @@ class DwdPhenoData(object):
 
     def nearest_station(self, latitude, longitude, all=False):
         """
-        Select most current stations datasets.
-
-        Stolen from https://github.com/marians/dwd-weather
+        Select closest station.
         """
-        closest = None
-        closest_distance = 99999999999
-        for index, station in self.get_stations(all=all).iterrows():
-            d = haversine_distance((longitude, latitude),
-                (station["geograph.Laenge"], station["geograph.Breite"]))
-            if d < closest_distance:
-                closest = station
-                closest_distance = d
-        return closest.to_frame()
+        return self.nearest_stations(latitude, longitude, all=all).head(1)
 
     def nearest_stations(self, latitude, longitude, all=False, limit=10):
         """
-        Select most current stations datasets.
+        Select closest stations.
 
         Stolen from https://github.com/marians/dwd-weather
         """
@@ -201,7 +189,7 @@ class DwdPhenoData(object):
 
         return observations
 
-    def get_forecast(self, options, humanize=False):
+    def get_forecast(self, options, forecast_year=None, humanize=False):
         """
         Forecast observations.
 
@@ -211,6 +199,11 @@ class DwdPhenoData(object):
         - Aggregate mean "day of the year" value of the "Jultag" values for each group
         """
 
+        # Compute target year.
+        target_year = datetime.today().year
+        if forecast_year is not None:
+            target_year = datetime.strptime(str(forecast_year), "%Y").year
+
         # Get current observations
         observations = self.get_observations(options)
 
@@ -230,7 +223,7 @@ class DwdPhenoData(object):
 
 
         # Compute ISO date from "day of the year" values and insert as new column
-        real_dates = pd.to_datetime(datetime.today().year * 1000 + forecast['Jultag'], errors='coerce', format='%Y%j')
+        real_dates = pd.to_datetime(target_year * 1000 + forecast['Jultag'], errors='coerce', format='%Y%j')
         forecast.insert(0, 'Datum', real_dates)
 
         # Resolve index column to real columns
@@ -250,7 +243,7 @@ class DwdPhenoData(object):
         # Optionally humanize DataFrame
         if humanize:
             megaframe = self.create_megaframe(forecast, drop_index_columns=True)
-            forecast = self.humanizer.get_forecast(megaframe)
+            forecast = self.humanizer.get_forecast(megaframe, target_year=target_year)
 
         # or pass-through with minor cosmetic amendments
         else:
@@ -260,8 +253,8 @@ class DwdPhenoData(object):
 
     def query(self, partition=None, files=None):
         """
-        The FTP/Pandas workhorse, converges data from multiple observation data
-        CSV files on upstream CDC FTP server into a single Pandas DataFrame object.
+        The FTP/pandas workhorse, converges data from multiple observation data
+        CSV files on upstream CDC FTP server into a single pandas DataFrame object.
 
         - Obtains ``partition`` parameter which can be either ``annual`` or ``immediate``.
         - Obtains optional ``files`` parameter which will be applied
@@ -279,7 +272,7 @@ class DwdPhenoData(object):
         results = pd.DataFrame()
 
         # Load multiple files into single DataFrame
-        for path in tqdm(paths, ncols=80):
+        for path in iterate_with_progressbar(paths):
 
             logger.debug('Processing file "{}"'.format(path))
 
@@ -294,7 +287,7 @@ class DwdPhenoData(object):
             # Coerce "Eintrittsdatum" column into date format
             data['Eintrittsdatum'] = pd.to_datetime(data['Eintrittsdatum'], errors='coerce', format='%Y%m%d')
 
-            results = results.append(data, sort=False)
+            results = pd.concat([results, data], sort=False)
 
         # Sanity checks
         if results.empty:
@@ -369,7 +362,7 @@ class DwdPhenoData(object):
             'phase-id': 'Phase_id',
         }
 
-        # Lowlevel filtering based on IDs
+        # Low-level filtering based on IDs
         # For each designated field, add ``.isin`` criteria to "boolean index" expression
         expression = True
         for key, field in list(isin_map.items()):
@@ -377,7 +370,8 @@ class DwdPhenoData(object):
                 continue
             reference = results[field]
             if key in criteria and criteria[key]:
-                expression &= reference.isin(criteria[key])
+                values = map(int, criteria[key])
+                expression &= reference.isin(values)
 
         # Apply filter expression to DataFrame
         if type(expression) is not bool:
@@ -474,7 +468,7 @@ class DwdPhenoData(object):
             raise KeyError(message)
 
 @attr.s
-class DwdPhenoDataHumanizer(object):
+class DwdPhenoDataHumanizer:
     """
     Bring result DataFrame in a more pleasant shape.
     """
@@ -506,7 +500,7 @@ class DwdPhenoDataHumanizer(object):
 
         return canvas
 
-    def get_forecast(self, frame):
+    def get_forecast(self, frame, target_year):
 
         canvas = pd.DataFrame()
 
@@ -519,6 +513,8 @@ class DwdPhenoDataHumanizer(object):
         canvas['Phase'] = phases
         canvas['Station'] = stations
 
+        canvas.insert(0, 'Jahr', target_year)
+
         return canvas
 
     def get_fields(self, frame):
