@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 # (c) 2018 Andreas Motl <andreas@hiveeyes.org>
-from builtins import object
 import os
 import re
 import sys
 import arrow
 import shutil
-import appdirs
+import platformdirs
 import logging
 import requests_ftp
 import dogpile.cache
@@ -15,12 +14,12 @@ from phenodata.util import regex_make_matchers, regex_run_matchers
 logger = logging.getLogger(__name__)
 
 
-class CacheManager(object):
+class CacheManager:
 
     def __init__(self):
 
         # Path to cache directory, system agnostic
-        self.cache_path = os.path.join(appdirs.user_cache_dir(appname='phenodata', appauthor=False), 'dwd-ftp')
+        self.cache_path = os.path.join(platformdirs.user_cache_dir(appname='phenodata', appauthor=False), 'dwd-ftp')
         if sys.version_info.major >= 3:
             self.cache_path = os.path.join(self.cache_path, 'py{}'.format(sys.version_info.major))
         if not os.path.exists(self.cache_path):
